pub enum CampaignEventType {
TcuDefense,
IhubDefense,
StationDefense,
StationFreeport,
Unrecognized,
}Expand description
The kind of structure a sovereignty campaign is about.
Variants
TcuDefense
Defense of a territorial claim unit.
IhubDefense
Defense of an infrastructure hub.
StationDefense
Defense of a station.
StationFreeport
Freeport of a station.
Unrecognized
A type this version of the crate does not know about.