pub enum ContainerPasswordType {
Config,
General,
Unrecognized,
}Expand description
The kind of password involved in a container log entry.
Variants
Config
Configuration password.
General
General password.
Unrecognized
A value this version of the crate does not know about.