pub enum EventOwnerType {
EveServer,
Corporation,
Faction,
Character,
Alliance,
Unrecognized,
}Expand description
The kind of entity that owns a calendar event.
Variants
EveServer
The game server.
Corporation
A corporation.
Faction
A faction.
Character
A character.
Alliance
An alliance.
Unrecognized
A value not known to this version of the crate.