pub enum ManufactureOwner {
Any,
Corporation,
Character,
Unrecognized,
}Expand description
Who must own the items of a manufacturing project.
Variants
Any
Anyone.
Corporation
A corporation.
Character
A character.
Unrecognized
A value this version of the crate does not know about.