pub enum NameCategory {
Alliance,
Character,
Constellation,
Corporation,
InventoryType,
Region,
SolarSystem,
Station,
Faction,
Unrecognized,
}Expand description
The kind of entity a resolved name belongs to.
Variants
Alliance
An alliance.
Character
A character.
Constellation
A constellation.
Corporation
A corporation.
InventoryType
An inventory type.
Region
A region.
SolarSystem
A solar system.
Station
A station.
Faction
A faction.
Unrecognized
A category this version of the crate does not know about.