pub enum PlanetType {
Temperate,
Barren,
Oceanic,
Ice,
Gas,
Lava,
Storm,
Plasma,
Unrecognized,
}Expand description
The type of a planet that supports planetary interaction.
Variants
Temperate
Temperate.
Barren
Barren.
Oceanic
Oceanic.
Ice
Ice.
Gas
Gas.
Lava
Lava.
Storm
Storm.
Plasma
Plasma.
Unrecognized
A value this version of the crate does not know about.