pub enum RoleType {
GrantableRoles,
GrantableRolesAtBase,
GrantableRolesAtHq,
GrantableRolesAtOther,
Roles,
RolesAtBase,
RolesAtHq,
RolesAtOther,
Unrecognized,
}Expand description
Which set of roles a role history entry changed.
Variants
GrantableRoles
Grantable roles.
GrantableRolesAtBase
Grantable roles at the base.
GrantableRolesAtHq
Grantable roles at the headquarters.
GrantableRolesAtOther
Grantable roles at other locations.
Roles
Roles.
RolesAtBase
Roles at the base.
RolesAtHq
Roles at the headquarters.
RolesAtOther
Roles at other locations.
Unrecognized
A value this version of the crate does not know about.