pub enum RoutePreference {
Shorter,
Safer,
LessSecure,
}Expand description
Which route to prefer when several are possible.
Variants
Shorter
The shortest route.
Safer
The route that avoids low and null security systems.
LessSecure
The route that prefers low and null security systems.