pub enum StandingLevel {
Bad,
Excellent,
Good,
Neutral,
Terrible,
Unrecognized,
}Expand description
The standing level that decides a customs office tax rate.
Variants
Bad
Bad standing.
Excellent
Excellent standing.
Good
Good standing.
Neutral
Neutral standing.
Terrible
Terrible standing.
Unrecognized
A value this version of the crate does not know about.