pub struct AssetsGroup<'a> { /* private fields */ }Expand description
Endpoints for Assets
Implementations
Sourceimpl AssetsGroup<'_>
impl AssetsGroup<'_>
Sourcepub async fn get_character_assets(
&self,
character_id: i64,
) -> EsiResult<Vec<Asset>>
pub async fn get_character_assets( &self, character_id: i64, ) -> EsiResult<Vec<Asset>>
Get a character’s assets.
Sourcepub async fn get_character_assets_locations(
&self,
character_id: i64,
item_ids: &[i64],
) -> EsiResult<Vec<AssetLocation>>
pub async fn get_character_assets_locations( &self, character_id: i64, item_ids: &[i64], ) -> EsiResult<Vec<AssetLocation>>
Get locations of some of a character’s assets.
The spec allows at most 1000 items per request; longer lists are split into several requests, sent concurrently, and the results are joined in order. An empty list sends nothing.
Sourcepub async fn get_character_assets_names(
&self,
character_id: i64,
item_ids: &[i64],
) -> EsiResult<Vec<AssetName>>
pub async fn get_character_assets_names( &self, character_id: i64, item_ids: &[i64], ) -> EsiResult<Vec<AssetName>>
Get names of some of a character’s assets.
The spec allows at most 1000 items per request; longer lists are split into several requests, sent concurrently, and the results are joined in order. An empty list sends nothing.
Sourcepub async fn get_corporation_assets(
&self,
corporation_id: i64,
) -> EsiResult<Vec<Asset>>
pub async fn get_corporation_assets( &self, corporation_id: i64, ) -> EsiResult<Vec<Asset>>
Get a corporation’s assets.
Requires the auth’d character to be a director/+ in the corp.
Sourcepub async fn get_corporation_assets_locations(
&self,
corporation_id: i64,
item_ids: &[i64],
) -> EsiResult<Vec<AssetLocation>>
pub async fn get_corporation_assets_locations( &self, corporation_id: i64, item_ids: &[i64], ) -> EsiResult<Vec<AssetLocation>>
Get locations of some of a corporation’s assets.
Requires the auth’d character to be a director/+ in the corp.
The spec allows at most 1000 items per request; longer lists are split into several requests, sent concurrently, and the results are joined in order. An empty list sends nothing.
Sourcepub async fn get_corporation_assets_names(
&self,
corporation_id: i64,
item_ids: &[i64],
) -> EsiResult<Vec<AssetName>>
pub async fn get_corporation_assets_names( &self, corporation_id: i64, item_ids: &[i64], ) -> EsiResult<Vec<AssetName>>
Get names of some of a corporation’s assets.
Requires the auth’d character to be a director/+ in the corp.
The spec allows at most 1000 items per request; longer lists are split into several requests, sent concurrently, and the results are joined in order. An empty list sends nothing.