pub struct CharacterGroup<'a> { /* private fields */ }Expand description
Endpoints for Character
Implementations
Sourceimpl CharacterGroup<'_>
impl CharacterGroup<'_>
Sourcepub async fn get_public_info(
&self,
character_id: i64,
) -> EsiResult<CharacterPublicInfo>
pub async fn get_public_info( &self, character_id: i64, ) -> EsiResult<CharacterPublicInfo>
Get a character’s public information.
Sourcepub async fn get_history(
&self,
character_id: i64,
) -> EsiResult<Vec<CharacterCorporationHistoryItem>>
pub async fn get_history( &self, character_id: i64, ) -> EsiResult<Vec<CharacterCorporationHistoryItem>>
Get a character’s corporation history.
Sourcepub async fn get_portrait(
&self,
character_id: i64,
) -> EsiResult<CharacterPortraitInfo>
pub async fn get_portrait( &self, character_id: i64, ) -> EsiResult<CharacterPortraitInfo>
Get a character’s portrait URLs on the image server.
Sourcepub async fn get_affiliation(
&self,
character_ids: &[i64],
) -> EsiResult<Vec<CharacterAffiliation>>
pub async fn get_affiliation( &self, character_ids: &[i64], ) -> EsiResult<Vec<CharacterAffiliation>>
Get character affiliations.
The spec allows at most 1000 items per request; longer lists are split into several requests, sent concurrently, and the results are joined in order. An empty list sends nothing.
Sourcepub async fn get_blueprints(
&self,
character_id: i64,
) -> EsiResult<Vec<Blueprint>>
pub async fn get_blueprints( &self, character_id: i64, ) -> EsiResult<Vec<Blueprint>>
Get character blueprints.
Sourcepub async fn get_notifications(
&self,
character_id: i64,
) -> EsiResult<Vec<Notification>>
pub async fn get_notifications( &self, character_id: i64, ) -> EsiResult<Vec<Notification>>
Get character notifications.
Sourcepub async fn get_wallet_transactions(
&self,
character_id: i64,
) -> EsiResult<Vec<WalletTransaction>>
pub async fn get_wallet_transactions( &self, character_id: i64, ) -> EsiResult<Vec<WalletTransaction>>
Get character wallet transactions.
Sourceimpl CharacterGroup<'_>
impl CharacterGroup<'_>
Sourcepub async fn get_agents_research(
&self,
character_id: i64,
) -> EsiResult<Vec<ResearchAgent>>
pub async fn get_agents_research( &self, character_id: i64, ) -> EsiResult<Vec<ResearchAgent>>
List the research agents of a character.
Sourcepub async fn get_fatigue(&self, character_id: i64) -> EsiResult<Fatigue>
pub async fn get_fatigue(&self, character_id: i64) -> EsiResult<Fatigue>
Get a character’s jump fatigue.
Sourcepub async fn get_medals(&self, character_id: i64) -> EsiResult<Vec<Medal>>
pub async fn get_medals(&self, character_id: i64) -> EsiResult<Vec<Medal>>
List the medals of a character.
Sourcepub async fn get_contact_notifications(
&self,
character_id: i64,
) -> EsiResult<Vec<ContactNotification>>
pub async fn get_contact_notifications( &self, character_id: i64, ) -> EsiResult<Vec<ContactNotification>>
List the contact standing change notifications of a character.
Sourcepub async fn get_roles(&self, character_id: i64) -> EsiResult<CharacterRoles>
pub async fn get_roles(&self, character_id: i64) -> EsiResult<CharacterRoles>
Get the corporation roles of a character.
Sourcepub async fn get_standings(&self, character_id: i64) -> EsiResult<Vec<Standing>>
pub async fn get_standings(&self, character_id: i64) -> EsiResult<Vec<Standing>>
List the standings of a character with agents, NPC corporations and factions.
Sourcepub async fn get_titles(
&self,
character_id: i64,
) -> EsiResult<Vec<CharacterTitle>>
pub async fn get_titles( &self, character_id: i64, ) -> EsiResult<Vec<CharacterTitle>>
List the corporation titles of a character.