pub struct Contract {Show 22 fields
pub acceptor_id: i64,
pub assignee_id: i64,
pub availability: ContractAvailability,
pub buyout: Option<f64>,
pub collateral: Option<f64>,
pub contract_id: i64,
pub date_accepted: Option<String>,
pub date_completed: Option<String>,
pub date_expired: String,
pub date_issued: String,
pub days_to_complete: Option<i64>,
pub end_location_id: Option<i64>,
pub for_corporation: bool,
pub issuer_corporation_id: i64,
pub issuer_id: i64,
pub price: Option<f64>,
pub reward: Option<f64>,
pub start_location_id: Option<i64>,
pub status: ContractStatus,
pub title: Option<String>,
pub contract_type: ContractType,
pub volume: Option<f64>,
}Expand description
A contract of a character or a corporation.
Fields
acceptor_id: i64ID of the character or corporation that accepted the contract
(0 if nobody did).
assignee_id: i64ID of the character, corporation or alliance the contract is assigned to.
availability: ContractAvailabilityWho can accept the contract.
buyout: Option<f64>Buyout price (auctions).
collateral: Option<f64>Collateral (couriers).
contract_id: i64ID of the contract.
date_accepted: Option<String>Date the contract was accepted.
date_completed: Option<String>Date the contract was completed.
date_expired: StringDate the contract expires.
date_issued: StringDate the contract was issued.
days_to_complete: Option<i64>Days to complete (couriers).
end_location_id: Option<i64>Destination location (couriers).
for_corporation: boolWhether the contract was issued on behalf of a corporation.
issuer_corporation_id: i64Corporation ID of the issuer.
issuer_id: i64Character ID of the issuer.
price: Option<f64>Price (item exchanges and auctions).
reward: Option<f64>Reward (couriers).
start_location_id: Option<i64>Start location.
status: ContractStatusStatus of the contract.
title: Option<String>Title of the contract.
contract_type: ContractTypeType of the contract.
volume: Option<f64>Volume of the items, in m3.