CorporationGroup

Struct CorporationGroup 

pub struct CorporationGroup<'a> { /* private fields */ }
Endpoints for Corporation

Implementations

Source

impl CorporationGroup<'_>

pub async fn get_public_info( &self, corporation_id: i64, ) -> EsiResult<CorporationPublicInfo>

Get a corporation’s public info.

pub async fn get_history( &self, corporation_id: i64, ) -> EsiResult<Vec<CorporationHistoryItem>>

Get a corporation’s alliance history.

pub async fn get_members(&self, corporation_id: i64) -> EsiResult<Vec<i64>>

Get a corporation’s member list.

Requires the auth’d character to be in the corporation.

pub async fn get_npc_corps(&self) -> EsiResult<Vec<i64>>

Get a list of NPC corporations.

pub async fn get_blueprints( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<Blueprint>>

Get the blueprints of a corporation.

Requires the Director role.

pub async fn get_container_logs( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<ContainerLogEntry>>

Get the container logs of a corporation.

Requires the Director role.

pub async fn get_divisions( &self, corporation_id: i64, ) -> EsiResult<CorporationDivisions>

Get the hangar and wallet divisions of a corporation.

Requires the Director role.

pub async fn get_facilities( &self, corporation_id: i64, ) -> EsiResult<Vec<CorporationFacility>>

Get the industry facilities of a corporation.

Requires the Factory Manager role.

pub async fn get_icons( &self, corporation_id: i64, ) -> EsiResult<CorporationIcons>

Get the icons of a corporation.

pub async fn get_medals( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<CorporationMedal>>

Get the medals created by a corporation.

pub async fn get_issued_medals( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<IssuedMedal>>

Get the medals issued by a corporation.

Requires the Director role.

pub async fn get_members_limit(&self, corporation_id: i64) -> EsiResult<i64>

Get the member limit of a corporation.

Requires the Director role.

pub async fn get_member_titles( &self, corporation_id: i64, ) -> EsiResult<Vec<MemberTitles>>

Get the titles of the members of a corporation.

Requires the Director role.

pub async fn get_member_tracking( &self, corporation_id: i64, ) -> EsiResult<Vec<MemberTracking>>

Track the members of a corporation.

Requires the Director role.

pub async fn get_roles( &self, corporation_id: i64, ) -> EsiResult<Vec<MemberRoles>>

Get the roles of the members of a corporation.

pub async fn get_roles_history( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<RoleHistoryEntry>>

Get the role changes of a corporation in the last 30 days.

Requires the Director role.

pub async fn get_shareholders( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<Shareholder>>

Get the shareholders of a corporation.

Requires the Director role.

pub async fn get_standings( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<Standing>>

Get the standings of a corporation.

pub async fn get_starbases( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<Starbase>>

Get the starbases of a corporation.

Requires the Director role.

pub async fn get_starbase( &self, corporation_id: i64, starbase_id: i64, system_id: i64, ) -> EsiResult<StarbaseDetails>

Get the settings of a starbase. system_id is the solar system the starbase is in.

Requires the Director role.

pub async fn get_structures( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<CorporationStructure>>

Get the structures of a corporation.

Requires the Station Manager role.

pub async fn get_titles( &self, corporation_id: i64, ) -> EsiResult<Vec<CorporationTitle>>

Get the titles of a corporation.

Requires the Director role.