pub struct CorporationProjectsGroup<'a> { /* private fields */ }Expand description
Endpoints for Corporation Projects
Implementations
Sourceimpl CorporationProjectsGroup<'_>
impl CorporationProjectsGroup<'_>
Sourcepub async fn list(
&self,
corporation_id: i64,
after: Option<String>,
before: Option<String>,
limit: Option<i64>,
state: Option<ProjectStateFilter>,
) -> EsiResult<Page<ProjectSummary>>
pub async fn list( &self, corporation_id: i64, after: Option<String>, before: Option<String>, limit: Option<i64>, state: Option<ProjectStateFilter>, ) -> EsiResult<Page<ProjectSummary>>
List the projects of a corporation. Use the cursor of the returned
page as after or before to walk through the list.
Sourcepub async fn get_project(
&self,
corporation_id: i64,
project_id: Uuid,
) -> EsiResult<Project>
pub async fn get_project( &self, corporation_id: i64, project_id: Uuid, ) -> EsiResult<Project>
Get the details of a project of a corporation.
Sourcepub async fn get_contribution(
&self,
corporation_id: i64,
project_id: Uuid,
character_id: i64,
) -> EsiResult<ProjectContribution>
pub async fn get_contribution( &self, corporation_id: i64, project_id: Uuid, character_id: i64, ) -> EsiResult<ProjectContribution>
Get what a character contributed to a project.
Sourcepub async fn list_contributors(
&self,
corporation_id: i64,
project_id: Uuid,
after: Option<String>,
before: Option<String>,
limit: Option<i64>,
) -> EsiResult<Page<ProjectContributor>>
pub async fn list_contributors( &self, corporation_id: i64, project_id: Uuid, after: Option<String>, before: Option<String>, limit: Option<i64>, ) -> EsiResult<Page<ProjectContributor>>
List the contributors to a project. Use the cursor of the returned
page as after or before to walk through the list.
Requires the Project Manager role.