pub struct FleetInvitation {
pub character_id: i64,
pub role: FleetRole,
pub squad_id: Option<i64>,
pub wing_id: Option<i64>,
}Expand description
The body of a request to invite a character to a fleet.
Fields
character_id: i64Character to invite.
role: FleetRoleRole to give the character.
squad_id: Option<i64>Squad to place the character in, when the role requires it.
wing_id: Option<i64>Wing to place the character in, when the role requires it.