pub struct FleetMovement {
pub role: FleetRole,
pub squad_id: Option<i64>,
pub wing_id: Option<i64>,
}Expand description
The body of a request to move a fleet member.
Fields
role: FleetRoleNew role of the member.
squad_id: Option<i64>New squad of the member, when the role requires it.
wing_id: Option<i64>New wing of the member, when the role requires it.