pub struct IndustryGroup<'a> { /* private fields */ }Expand description
Endpoints for Industry
Implementations
Sourceimpl IndustryGroup<'_>
impl IndustryGroup<'_>
Sourcepub async fn get_industry_systems(&self) -> EsiResult<Vec<IndustrialSystem>>
pub async fn get_industry_systems(&self) -> EsiResult<Vec<IndustrialSystem>>
Returns a list of solar systems with the cost index for every activity
Sourcepub async fn get_character_industry_jobs(
&self,
character_id: i64,
include_completed: Option<bool>,
) -> EsiResult<Vec<IndustryJob>>
pub async fn get_character_industry_jobs( &self, character_id: i64, include_completed: Option<bool>, ) -> EsiResult<Vec<IndustryJob>>
List industry jobs placed by a character
Sourceimpl IndustryGroup<'_>
impl IndustryGroup<'_>
Sourcepub async fn get_facilities(&self) -> EsiResult<Vec<IndustryFacility>>
pub async fn get_facilities(&self) -> EsiResult<Vec<IndustryFacility>>
List the public industry facilities.
Sourceimpl IndustryGroup<'_>
impl IndustryGroup<'_>
Sourcepub async fn get_character_mining(
&self,
character_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<MiningEntry>>
pub async fn get_character_mining( &self, character_id: i64, page: Option<i32>, ) -> EsiResult<Vec<MiningEntry>>
Paginated record of the mining done by a character in the last 30 days.
Sourcepub async fn get_corporation_mining_extractions(
&self,
corporation_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<MiningExtraction>>
pub async fn get_corporation_mining_extractions( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<MiningExtraction>>
Moon mining extractions of a corporation.
Sourcepub async fn get_corporation_mining_observers(
&self,
corporation_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<MiningObserver>>
pub async fn get_corporation_mining_observers( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<MiningObserver>>
Structures that observed mining for a corporation.
Sourcepub async fn get_corporation_mining_observer(
&self,
corporation_id: i64,
observer_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<ObservedMining>>
pub async fn get_corporation_mining_observer( &self, corporation_id: i64, observer_id: i64, page: Option<i32>, ) -> EsiResult<Vec<ObservedMining>>
Mining recorded by one observer structure of a corporation.
Sourcepub async fn get_corporation_industry_jobs(
&self,
corporation_id: i64,
include_completed: Option<bool>,
page: Option<i32>,
) -> EsiResult<Vec<CorporationIndustryJob>>
pub async fn get_corporation_industry_jobs( &self, corporation_id: i64, include_completed: Option<bool>, page: Option<i32>, ) -> EsiResult<Vec<CorporationIndustryJob>>
List industry jobs placed by a corporation.