pub struct MarketGroup<'a> { /* private fields */ }Expand description
Endpoints for Market
Implementations
Sourceimpl MarketGroup<'_>
impl MarketGroup<'_>
Sourcepub async fn get_region_history(
&self,
region_id: i64,
type_id: i64,
) -> EsiResult<Vec<HistoryItem>>
pub async fn get_region_history( &self, region_id: i64, type_id: i64, ) -> EsiResult<Vec<HistoryItem>>
Get a list of historical market statistics for the specified type in a region
Sourcepub async fn get_region_orders(
&self,
region_id: i64,
order_type: Option<String>,
page: Option<i32>,
type_id: Option<i64>,
) -> EsiResult<Vec<MarketOrder>>
pub async fn get_region_orders( &self, region_id: i64, order_type: Option<String>, page: Option<i32>, type_id: Option<i64>, ) -> EsiResult<Vec<MarketOrder>>
Get a list of orders in a region
Sourcepub async fn get_market_prices(&self) -> EsiResult<Vec<PriceItem>>
pub async fn get_market_prices(&self) -> EsiResult<Vec<PriceItem>>
Get a list of average and adjusted prices
Sourcepub async fn get_character_orders(
&self,
character_id: i64,
) -> EsiResult<Vec<CharacterOrder>>
pub async fn get_character_orders( &self, character_id: i64, ) -> EsiResult<Vec<CharacterOrder>>
List open market orders placed by a character
Sourceimpl MarketGroup<'_>
impl MarketGroup<'_>
Sourcepub async fn get_groups(&self) -> EsiResult<Vec<i64>>
pub async fn get_groups(&self) -> EsiResult<Vec<i64>>
List the IDs of all market groups.
Sourcepub async fn get_group(
&self,
market_group_id: i64,
) -> EsiResult<MarketGroupInfo>
pub async fn get_group( &self, market_group_id: i64, ) -> EsiResult<MarketGroupInfo>
Get information about a market group.
Sourceimpl MarketGroup<'_>
impl MarketGroup<'_>
Sourcepub async fn get_character_orders_history(
&self,
character_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<CharacterOrderHistory>>
pub async fn get_character_orders_history( &self, character_id: i64, page: Option<i32>, ) -> EsiResult<Vec<CharacterOrderHistory>>
List cancelled and expired market orders placed by a character (up to 90 days).
Sourcepub async fn get_corporation_orders(
&self,
corporation_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<CorporationOrder>>
pub async fn get_corporation_orders( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<CorporationOrder>>
List open market orders placed on behalf of a corporation.
Sourcepub async fn get_corporation_orders_history(
&self,
corporation_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<CorporationOrderHistory>>
pub async fn get_corporation_orders_history( &self, corporation_id: i64, page: Option<i32>, ) -> EsiResult<Vec<CorporationOrderHistory>>
List cancelled and expired market orders placed on behalf of a corporation.
Sourcepub async fn get_structure_orders(
&self,
structure_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<StructureOrder>>
pub async fn get_structure_orders( &self, structure_id: i64, page: Option<i32>, ) -> EsiResult<Vec<StructureOrder>>
List orders in a structure’s market.