pub struct StarbaseDetails {Show 14 fields
pub allow_alliance_members: bool,
pub allow_corporation_members: bool,
pub anchor: StarbasePermission,
pub attack_if_at_war: bool,
pub attack_if_other_security_status_dropping: bool,
pub attack_security_status_threshold: Option<f64>,
pub attack_standing_threshold: Option<f64>,
pub fuel_bay_take: StarbasePermission,
pub fuel_bay_view: StarbasePermission,
pub fuels: Vec<StarbaseFuel>,
pub offline: StarbasePermission,
pub online: StarbasePermission,
pub unanchor: StarbasePermission,
pub use_alliance_standings: bool,
}Expand description
The settings of a starbase.
Fields
allow_alliance_members: boolWhether alliance members may use the starbase.
allow_corporation_members: boolWhether corporation members may use the starbase.
anchor: StarbasePermissionWho can anchor.
attack_if_at_war: boolWhether the starbase attacks entities at war with it.
attack_if_other_security_status_dropping: boolWhether the starbase attacks entities with dropping security status.
attack_security_status_threshold: Option<f64>Security status threshold for attacks.
attack_standing_threshold: Option<f64>Standing threshold for attacks.
fuel_bay_take: StarbasePermissionWho can take from the fuel bay.
fuel_bay_view: StarbasePermissionWho can view the fuel bay.
fuels: Vec<StarbaseFuel>Fuel in the starbase.
offline: StarbasePermissionWho can take it offline.
online: StarbasePermissionWho can bring it online.
unanchor: StarbasePermissionWho can unanchor.
use_alliance_standings: boolWhether alliance standings are used.