pub struct UserInterfaceGroup<'a> { /* private fields */ }Expand description
Endpoints for UserInterface
Implementations
Sourceimpl UserInterfaceGroup<'_>
impl UserInterfaceGroup<'_>
Sourcepub async fn open_market_details_window(&self, type_id: i64) -> EsiResult<()>
pub async fn open_market_details_window(&self, type_id: i64) -> EsiResult<()>
Open the market details window.
Sourceimpl UserInterfaceGroup<'_>
impl UserInterfaceGroup<'_>
Sourcepub async fn set_autopilot_waypoint(
&self,
destination_id: i64,
add_to_beginning: bool,
clear_other_waypoints: bool,
) -> EsiResult<()>
pub async fn set_autopilot_waypoint( &self, destination_id: i64, add_to_beginning: bool, clear_other_waypoints: bool, ) -> EsiResult<()>
Set a solar system, station or structure as an autopilot waypoint in the client.
Sourcepub async fn open_contract_window(&self, contract_id: i64) -> EsiResult<()>
pub async fn open_contract_window(&self, contract_id: i64) -> EsiResult<()>
Open the contract window in the client.
Sourcepub async fn open_information_window(&self, target_id: i64) -> EsiResult<()>
pub async fn open_information_window(&self, target_id: i64) -> EsiResult<()>
Open the information window of a character, corporation or alliance in the client.
Sourcepub async fn open_new_mail_window(&self, mail: &NewMailWindow) -> EsiResult<()>
pub async fn open_new_mail_window(&self, mail: &NewMailWindow) -> EsiResult<()>
Open the new mail window in the client with the given content.