pub struct WalletGroup<'a> { /* private fields */ }Expand description
Endpoints for Wallet
Implementations
Sourceimpl WalletGroup<'_>
impl WalletGroup<'_>
Sourcepub async fn get_wallet(&self, character_id: i64) -> EsiResult<f64>
pub async fn get_wallet(&self, character_id: i64) -> EsiResult<f64>
Returns a character’s wallet balance
Sourceimpl WalletGroup<'_>
impl WalletGroup<'_>
Sourcepub async fn get_journal(
&self,
character_id: i64,
page: Option<i32>,
) -> EsiResult<Vec<JournalEntry>>
pub async fn get_journal( &self, character_id: i64, page: Option<i32>, ) -> EsiResult<Vec<JournalEntry>>
Get a character’s wallet journal for the last 30 days.
Sourceimpl WalletGroup<'_>
impl WalletGroup<'_>
Sourcepub async fn get_corporation_wallets(
&self,
corporation_id: i64,
) -> EsiResult<Vec<DivisionBalance>>
pub async fn get_corporation_wallets( &self, corporation_id: i64, ) -> EsiResult<Vec<DivisionBalance>>
Get the balance of every wallet division of a corporation.
Sourcepub async fn get_corporation_journal(
&self,
corporation_id: i64,
division: i64,
page: Option<i32>,
) -> EsiResult<Vec<JournalEntry>>
pub async fn get_corporation_journal( &self, corporation_id: i64, division: i64, page: Option<i32>, ) -> EsiResult<Vec<JournalEntry>>
Get the journal of a corporation wallet division for the last 30 days.
Sourcepub async fn get_corporation_transactions(
&self,
corporation_id: i64,
division: i64,
from_id: Option<i64>,
) -> EsiResult<Vec<CorporationWalletTransaction>>
pub async fn get_corporation_transactions( &self, corporation_id: i64, division: i64, from_id: Option<i64>, ) -> EsiResult<Vec<CorporationWalletTransaction>>
Get the market transactions of a corporation wallet division.
Pass the lowest transaction_id of the previous page as from_id to continue.