Module prelude

Module prelude 

Module for easy imports.

Re-exports

pub use crate::spec::Spec;

Structs

AuthenticationInformation
AuthenticationInformation contains data needed to complete the requested authentication flow.
Esi
Struct to interact with ESI.
EsiBuilder
Builder for the Esi struct.
RateLimitStatus
Latest rate-limit state ESI reported for one route group.
TokenClaims
Access token (JWT) payload.

Enums

ErrorLimitStatus
Whether ESI’s legacy error limit (X-Esi-Error-Limit-* headers) is currently blocking requests from this client.
EsiError
Errors that can occur when dealing with ESI.
RequestType
Which base URL to start with - the public URL for unauthenticated calls, or the authenticated URL for making calls to endpoints that require an access token.

Constants

COMPATIBILITY_DATE_DEFAULT
The default compatibility date to use if none is specified in the builder: the latest date listed by https://esi.evetech.net/meta/compatibility-dates when this version was released.

Type Aliases

EsiResult
Crate Result wrapper.
PkceVerifier
PKCEVerifier is a base64urlencoded String to send in the body of the token request alongside the code returned from the ESI and the Client ID