pub enum RequestType {
Public,
Authenticated,
}Expand description
Which base URL to start with - the public URL for unauthenticated calls, or the authenticated URL for making calls to endpoints that require an access token.
Variants
Public
Endpoints that do not require authentication
Authenticated
Endpoints that require acting on behalf of an authenticated character