pub struct AuthenticationInformation {
pub authorization_url: String,
pub state: String,
pub pkce_verifier: Option<PkceVerifier>,
}Expand description
AuthenticationInformation contains data needed to complete the requested authentication flow.
Fields
URL to call/pass to users to initiate an authentication and get an auth code from ESI.
state: StringIf the default feature “random_state” is enabled, the returned state field string will be random; otherwise it’ll be “esi_openapi_unused”. The ESI docs link to this auth0 page to explain. You need to check the state yourself when the response from ESI is received.
pkce_verifier: Option<PkceVerifier>Filled if you’ve selected PKCE authentication for application. You will need it to authenticate using the code received from ESI.