EsiBuilder

Struct EsiBuilder 

pub struct EsiBuilder { /* private fields */ }
Builder for the Esi struct.

Example

let mut esi = EsiBuilder::new()
    .user_agent("some user agent")
    .client_id("your_client_id")
    .client_secret("your_client_secret")
    .callback_url("your_callback_url")
    .build()
    .unwrap();

Overriding the API specification

If you will be creating multiple struct instances, you will probably run into the issue of needing to retrieve the API spec on each. Given that this operation is fairly expensive (certainly as far as the rest of the API endpoints that EVE makes available), this builder supports setting that struct:

let mut esi = EsiBuilder::new()
    .user_agent("some user agent")
    .spec(Some(your_spec))
    .build()
    .unwrap();

Note that this “spec” function is just another builder function; you can make use it alongside all of the others. Note also that this is entirely optional: if you don’t mind retrieving the spec from ESI on each of your struct instances, you can safely ignore this.

Not including client info

If you are only making calls to non-authenticated endpoints, then you don’t need to make use of the authentication flow, which means you don’t need a client ID, client secret, and callback URL. In this case, you can construct your client without those parameters:

let mut esi = EsiBuilder::new()
    .user_agent("some user agent")
    .build()
    .unwrap();

Note that you still need to set the user agent, as this is good API usage behavior.

Implementations

Source

impl EsiBuilder

pub fn new() -> Self

Start a new builder.

pub fn compatibility_date(self, val: &str) -> Self

Set the compatibility header to use.

Will default to a hardcoded value if not set.

pub fn client_id(self, val: &str) -> Self

Set the client_id.

pub fn client_secret(self, val: &str) -> Self

Set the client_secret (https://docs.esi.evetech.net/docs/sso/web_based_sso_flow.html).

pub fn enable_application_authentication(self, val: bool) -> Self

Enable PKCE Authentication flow for Applications (https://docs.esi.evetech.net/docs/sso/native_sso_flow.html)

pub fn callback_url(self, val: &str) -> Self

Set the callback_url.

pub fn base_api_url(self, val: &str) -> Self

Set the base_api_url.

pub fn authorize_url(self, val: &str) -> Self

Set the authorize_url.

pub fn token_url(self, val: &str) -> Self

Set the token_url.

pub fn spec_url(self, val: &str) -> Self

Set the spec_url.

pub fn scope(self, val: &str) -> Self

Set the scope.

pub fn access_token(self, val: Option<&str>) -> Self

Set the access_token.

pub fn access_expiration(self, val: Option<i64>) -> Self

Set the access_expiration.

pub fn refresh_token(self, val: Option<&str>) -> Self

Set the refresh_token.

pub fn user_agent(self, val: &str) -> Self

Set the user_agent.

pub fn http_timeout(self, val: Option<u64>) -> Self

Set the timeout to use in millis when sending HTTP requests.

Will default to 60,000 (1 minute) if not set.

pub fn spec(self, spec: Option<Spec>) -> Self

Explicitly set the OpenAPI specification.

Allows copying the spec from another Esi struct or other source, avoiding fetching the spec from ESI again. May be useful given the runtime cost of retrieving the spec.

Be aware of the potential for out-of-date data.

pub fn build(self) -> EsiResult<Esi>

Construct the Esi instance.

There are a few things that could go wrong, like not setting one of the mandatory fields or providing a user agent that is not a valid HTTP header value.