PkceVerifier

Type Alias PkceVerifier 

pub type PkceVerifier = String;
PKCEVerifier is a base64urlencoded String to send in the body of the token request alongside the code returned from the ESI and the Client ID

Aliased Type

pub struct PkceVerifier { /* private fields */ }