pub type PkceVerifier = String;Expand description
PKCEVerifier is a base64urlencoded String to send in the body of the token request alongside the code returned from the ESI and the Client ID
Aliased Type
pub struct PkceVerifier { /* private fields */ }